==> green-core-1.41.1.tgz: package/components/radio/radio-group.js <==
import "../../chunks/chunk.7TCXY7BP.js";
import {
  constrainSlots
} from "../../chunks/chunk.KBYQYDL3.js";
import {
  __decorateClass,
  __privateAdd,
  __privateSet
} from "../../chunks/chunk.5VURDMKE.js";

// libs/core/src/components/radio/radio-group.ts
import { LitElement, html } from "lit";
import { customElement, property } from "lit/decorators.js";
var _internals;
var GdsRadioGroup = class extends LitElement {
  constructor() {
    super();
    // Private members
    __privateAdd(this, _internals, void 0);
    this.label = "Label";
    this.inputElement = null;
    this.exludeAttr = ["id", "label"];
    __privateSet(this, _internals, this.attachInternals());
    constrainSlots(this);
  }
  reflectAttributesToInput() {
    if (this.inputElement) {
      const attributes = this.attributes;
      for (let i = 0; i < attributes.length; i++) {
        const attribute = attributes[i];
        if (!this.exludeAttr.includes(attribute.name)) {
          this.inputElement.setAttribute(attribute.name, attribute.value);
        }
      }
    }
  }
  update(changedProperties) {
    var _a;
    super.update(changedProperties);
    if (!this.inputElement) {
      this.inputElement = (_a = this.shadowRoot) == null ? void 0 : _a.getElementById(
        "radio"
      );
    }
    this.reflectAttributesToInput();
  }
  render() {
    return html`
      <fieldset
        class="gds-radio-group"
        role="radiogroup"
        aria-labelledby="label"
      >
        <label>${this.label}</label>
        <slot></slot>
      </fieldset>
    `;
  }
};
_internals = new WeakMap();
// static styles = unsafeCSS(styles)
GdsRadioGroup.shadowRootOptions = {
  mode: "open",
  delegatesFocus: true
};
__decorateClass([
  property({ type: String, reflect: true, attribute: "label" })
], GdsRadioGroup.prototype, "label", 2);
GdsRadioGroup = __decorateClass([
  customElement("gds-radio-group")
], GdsRadioGroup);
export {
  GdsRadioGroup
};

==> green-core-1.44.0.tgz: package/components/radio/radio-group.js <==
import "../../chunks/chunk.7TCXY7BP.js";
import {
  constrainSlots
} from "../../chunks/chunk.KBYQYDL3.js";
import {
  __decorateClass,
  __privateAdd,
  __privateSet
} from "../../chunks/chunk.SEHSDSX2.js";

// libs/core/src/components/radio/radio-group.ts
import { LitElement, html } from "lit";
import { customElement, property } from "lit/decorators.js";
var _internals;
var GdsRadioGroup = class extends LitElement {
  constructor() {
    super();
    // Private members
    __privateAdd(this, _internals, void 0);
    this.label = "Label";
    this.inputElement = null;
    this.exludeAttr = ["id", "label"];
    __privateSet(this, _internals, this.attachInternals());
    constrainSlots(this);
  }
  reflectAttributesToInput() {
    if (this.inputElement) {
      const attributes = this.attributes;
      for (let i = 0; i < attributes.length; i++) {
        const attribute = attributes[i];
        if (!this.exludeAttr.includes(attribute.name)) {
          this.inputElement.setAttribute(attribute.name, attribute.value);
        }
      }
    }
  }
  update(changedProperties) {
    var _a;
    super.update(changedProperties);
    if (!this.inputElement) {
      this.inputElement = (_a = this.shadowRoot) == null ? void 0 : _a.getElementById(
        "radio"
      );
    }
    this.reflectAttributesToInput();
  }
  render() {
    return html`
      <fieldset
        class="gds-radio-group"
        role="radiogroup"
        aria-labelledby="label"
      >
        <label>${this.label}</label>
        <slot></slot>
      </fieldset>
    `;
  }
};
_internals = new WeakMap();
// static styles = unsafeCSS(styles)
GdsRadioGroup.shadowRootOptions = {
  mode: "open",
  delegatesFocus: true
};
__decorateClass([
  property({ type: String, reflect: true, attribute: "label" })
], GdsRadioGroup.prototype, "label", 2);
GdsRadioGroup = __decorateClass([
  customElement("gds-radio-group")
], GdsRadioGroup);
export {
  GdsRadioGroup
};
